pub enum TermGraphemeError {
InvalidControl(InvalidControl),
DiacriticAtStart(DiacriticAtStart),
NotAGrapheme(NotAGrapheme),
}Expand description
Possible errors when creating a
TermGrapheme.
Variants
InvalidControl(InvalidControl)
Invalid control character found in the given input string.
DiacriticAtStart(DiacriticAtStart)
The given input string starts with a diacritic.
NotAGrapheme(NotAGrapheme)
The given input is not made of only one grapheme
(TermGrapheme).